use crate::error::InvalidValue;
use crate::quantity::{DeciDegreesCelsius, MilliVolts, Quantity};

#[inline]
pub fn convert(
    voltage: MilliVolts<i16>,
) -> Result<DeciDegreesCelsius<i16>, InvalidValue> {
    const MIN_VOLTAGE: MilliVolts<i16> = MilliVolts(-550);
    const MAX_VOLTAGE: MilliVolts<i16> = MilliVolts(1_500);

    if voltage >= MIN_VOLTAGE && voltage <= MAX_VOLTAGE {
        Ok(DeciDegreesCelsius(voltage.value()))
    } else {
        Err(InvalidValue)
    }
}
